| checkFiles | R Documentation |
checkFiles verifies whether all specified files are valid source files
that can be executed independently of each other. If an error occurs, the following actions are taken:
If open is either a function name or a function with a file parameter, then checkFiles
will attempt to open the faulty source file; otherwise, it will not.
The execution of checkFiles is stopped.
If you do not want the faulty source file to be opened immediately, use open=0.
Three modes are available for checking a file:
exist: Does the source file exist?
parse: (default) Is parse(file) (in R) or python -m py_compile "file" (in Python) successful?
run: Is Rscript "file" (in R) or reticulate::py_run_file(file) (in Python) successful?
If source files have side effects, e.g., generating an image or producing other outputs,
and mode == "parse", these side effects will occur during the check.
To prevent a script from being executed during the check, add a ## Not check: comment at the top of the script.
checkFiles(
files,
index = seq_along(files),
path = NULL,
open = openFile,
mode = c("parse", "run", "exist"),
...
)
Rsolo(
files,
index = seq_along(files),
path = NULL,
open = openFile,
mode = c("parse", "run", "exist"),
...
)
files |
character: file name(s) |
index |
integer(s): if |
path |
character: path to start from (default: |
open |
function: function or function name to call after an error occurs (default: |
mode |
character which check to do |
... |
further parameters given to the function in |
nothing
if (interactive()) {
files <- list.files(pattern="*.(R|py)$", full.names=TRUE, recursive=TRUE)
checkFiles(files)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.