| defaultApp | R Documentation |
Tries to open the given file with the default application of the operating system using base::system2().
Only Windows (windows), macOS (darwin), Linux (linux) and FreeBSD (freebsd) is supported.
defaultApp(file, wait = FALSE, ...)
file |
character: file name |
wait |
logical: indicates whether the R interpreter should wait for the command to finish, or run it asynchronously (default: |
... |
further arguments passed to |
Result of try(system2, ...), invisibly
if (interactive()) {
ghget()
defaultApp(ghlist("dataanalysis.pdf", full.names = TRUE))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.