| ghinstall | R Documentation |
If the user agrees, it installs additional software necessary for running a script.
Currently, only type=="py" for Python scripts and type=="R"`` for R scripts are supported. When a repository is downloaded, ghinstallis called once. If the user callsghinstallfor an update, the parameterforce=TRUE' must be set.
ghinstall(type = c("py", "R"), force = FALSE)
type |
character: programm type (default: |
force |
logical: should the installation really done (default: 'NA) |
Rmmstat4 init_R.R is opened if present in the active repository.
pymmstat4 internally utilizes a virtual environment named mmstat4.xxxx,
where xxxx, varies depending on the repository. When ghinstallis invoked, it verifies the existence of the virtual environmentmmstat4.xxxx. If it does not exist, the environment is created, and init_py.R'
is opened if present in the active repository.
NULL if type is not found, otherwise type
# to delete the virtual environment use
# reticulate::virtualenv_remove('mmstat4')
if (interactive()) ghinstall()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.