| ghrepos | R Documentation |
If key is NULL, then it returns the known repositories and where they are stored.
If key is not NULL, then possible addresses for a repository are returned .
ghrepos(key = NULL)
key |
character: "name" of the repository to find (default: |
a data frame with the data about the repositories
ghrepos()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.